@@ -9,7 +9,7 @@ from .helpers import _split_params_and_files
 
 class Tumblpy(object):
     def __init__(self, app_key=None, app_secret=None, oauth_token=None,
-                 oauth_token_secret=None, headers=None):
+                 oauth_token_secret=None, headers=None, proxies=None):
 
         # Define some API URLs real quick
         self.base_api_url = 'https://api.tumblr.com'
@@ -42,6 +42,7 @@ class Tumblpy(object):
                               self.oauth_token, self.oauth_token_secret)
 
         self.client = requests.Session()
+        self.client.proxies = proxies
         self.client.headers = req_headers
         self.client.auth = auth
 
@@ -185,5 +186,35 @@ class Tumblpy(object):
         size = [str(size)] or ['64']
         return self.get('avatar', blog_url=blog_url, extra_endpoints=size)
 
+    def following(self, kwargs=None):
+        """
+        Gets the blogs that the current user is following.
+        :param limit: an int, the number of likes you want returned
+        :param offset: an int, the blog you want to start at, for pagination.
+
+            # Start at the 20th blog and get 20 more blogs.
+            client.following({'offset': 20, 'limit': 20})
+
+        :returns: A dict created from the JSON response
+        """
+        return self.get('user/following', params=kwargs)
+
+    def dashboard(self, kwargs=None):
+        """
+        Gets the dashboard of the current user
+        example: dashboard = client.dashboard({'limit': '3'})
+
+
+        :param limit: an int, the number of posts you want returned
+        :param offset: an int, the posts you want to start at, for pagination.
+        :param type:   the type of post you want to return
+        :param since_id:  return only posts that have appeared after this ID
+        :param reblog_info: return reblog information about posts
+        :param notes_info:  return notes information about the posts
+
+        :returns: A dict created from the JSON response
+        """
+        return self.get('user/dashboard', params=kwargs)
+
     def __repr__(self):
         return u'<TumblrAPI: %s>' % self.app_key
